﻿'--------------------------------------------
'Author:   Dr. Fritz Faulhaber GmbH & Co. KG
'Date:     2020-10-22
'--------------------------------------------
'Description:   Extension of the MotionFunctions.bi for general purpose
'--------------------------------------------
#INCLUDE "MotionParameters.bi"   'right mouse click opens the file

'-------------------------------------------
' IsInput(pin)
' results in true IF the referred input pin
' is logically true
' otherwise false
'
'-------------------------------------------
   
FUNCTION IsInput(Pin)
DIM Mask = 1 << (Pin - 1)                 

RETURN (GETOBJ DigitalInputLogicalState) & Mask

END FUNCTION  
  
'-------------------------------------------
' SetOutput(pin,level)
' set a single DigOut TO either
' 0: is at low level - so would drive a LED
' 1: is at high lebel - so a LED OR brake would be deactivated
'
'-------------------------------------------

FUNCTION SetOutput(pin,level)
DIM Mask = $FF  'Default value. Would NOT change any outputs
DIM LowMask =  ~($3 << ((pin - 1)*2)) 'force a 11 11 11 00 to the desired pin                          
DIM HighMask = ~($2 << ((pin - 1)*2)) 'force a 11 11 11 10 to the desired pin                                     

IF level > 0 THEN
   Mask = Mask & HighMask
ELSE
   Mask = Mask & LowMask
END IF

'now set the outputs
SETOBJ WriteDigitalOutputs = Mask                   

END FUNCTION

'-------------------------------------------
' StartHomingMethod(method)
' configure a homing method and start the 
' homing. Any switches to be used in the method
' have TO be configured beforehand
'
'-------------------------------------------
                              
FUNCTION StartHomingMethod(method)          

'now configure opMode Homing 
SETOBJ HomingMethod = method
'only now start the homing
StartHoming()

END FUNCTION

'-------------------------------------------
' StartHoming()
' starts the preconfigured homing
'
'-------------------------------------------

 
FUNCTION StartHoming()          
DIM newCW = CiACmdEnableOperation  

SETOBJ ModesOfOperation = OpModeHoming

SETOBJ Controlword = newCW
SETOBJ Controlword = newCW | CiACmdStartBit
SETOBJ Controlword = newCW

END FUNCTION
                                                   
'-------------------------------------------
' isHomingFinshed()
' checks after a homing has been started
' whether it has been finished
' returns true if finished
' returns false if not finished

FUNCTION isHomingFinished()
DIM FinishedMask = CiAStatus_InPosBit | CiAStatus_AckBit

RETURN ((GETOBJ Statusword & FinishedMask) = FinishedMask)

END FUNCTION


             
